<?php
/**
 * Namespace Tecfood\Integracao\Services
 *
 * PHP version 5
 *
 * @category Php
 * @package  Tecfood\Integracao\Services
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Teknisa\Logic\IntNutrientes\Services;

use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use Planejamento\Entities\Nutrprod;
use Planejamento\Repositories\Nutrprod as NutrprodRepository;
use Setforms2\Shared\ORM\DateTime;
use Setforms2\Shared\Registry;
use Teknisa\Entities\SitLogtek;
use Teknisa\Entities\SitProdutoint;
use Teknisa\Repositories\SitProdutoint as SitProdutointRepository;


/**
 * Class EnviaProdutos
 *
 * PHP version 5
 *
 * @category Php
 * @package  Teknisa\Logic\IntNutrientes\Services
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class EnviaProdutos
{

    /**
     * Envia os Produtos para o Cliente
     *
     * @param Array  $prods     Produtos
     * @param String $nrorg     Organização
     * @param String $nrremessa Número da Remessa
     * @param String $nrorgint  Organização Integração
     *
     * @return string.
     * @throws \Exception
     */
    public static function enviaProdutos($prods, $nrorg, $nrremessa, $nrorgint)
    {
        if (empty($prods) === true) {
            //return tk_get_message_by_name('msg_ger07600_nenhumProdutoLiberado');
            return null;
        }

        $json  = array();

        //Define a Data Atual
        $dataAtual  = now();
        if ($dataAtual instanceof DateTime) {
            $dataAtual = DateUtil::truncateData($dataAtual);
        } else {
            $dataAtual = explode(' ', $dataAtual);
            $dataAtual = $dataAtual[0];
            $dataAtual = DateUtil::getDataDeString($dataAtual);
        }

        //Atualiza a Data de Envio do Produto
        $conn = Registry::getEntityManager();
        try {
            $conn->beginTransaction();

            $i = 0;
            foreach ($prods as $prod) {

                $json[$i]['NRORGINT']     = $prod['NRORGINT'];
                $json[$i]['NRREMESSAORI'] = $prod['NRREMESSA'];
                $json[$i]['NRREMESSARET'] = $nrremessa;
                $json[$i]['CDPRODUTOINT'] = $prod['CDPRODUTOINT'];
                $json[$i]['QTPESOINT']    = $prod['QTPESOINT'];
                $json[$i]['IDATIVO']      = $prod['IDATIVO'];
                $json[$i]['NUTRPROD']     = array();

                $nutrprod = Nutrprod::buscaNutrprod(
                    $nrorg, $prod['CDPRODUTO']
                );

                if (is_array($nutrprod)) {
                    $j = 0;
                    foreach ($nutrprod as $nutr) {
                        if ($nutr instanceof Nutrprod) {
                            $json[$i]['NUTRPROD'][$j]['CDPRODUTO']
                                = $nutr->getCdproduto();
                            $json[$i]['NUTRPROD'][$j]['CDNUTRIENTE']
                                = $nutr->getCdnutriente();
                            $json[$i]['NUTRPROD'][$j]['QTNUTRPROD']
                                = $nutr->getQtnutrprod();
                            $json[$i]['NUTRPROD'][$j]['DTULTATUNUPR']
                                = $dataAtual;
                            $json[$i]['NUTRPROD'][$j]['DSFONTNUTR']
                                = $nutr->getDsfontnutr();
                            $json[$i]['NUTRPROD'][$j]['NRORG']
                                = $nutr->getNrorg();
                            $json[$i]['NUTRPROD'][$j]['DTINCLUSAO']
                                = $dataAtual;
                            $json[$i]['NUTRPROD'][$j]['DTULTATU']
                                = $dataAtual;
                            $json[$i]['NUTRPROD'][$j]['NRORGINCLUSAO']
                                = $nutr->getNrorginclusao();
                            $json[$i]['NUTRPROD'][$j]['CDOPERINCLUSAO']
                                = $nutr->getCdoperinclusao();
                            $json[$i]['NUTRPROD'][$j]['NRORGULTATU']
                                = $nutr->getNrorgultatu();
                            $json[$i]['NUTRPROD'][$j]['CDOPERULTATU']
                                = $nutr->getCdoperultatu();
                            $json[$i]['NUTRPROD'][$j]['IDATIVO'] = 'S';

                            $j++;
                        }
                    }
                }

                SitProdutoint::atualizaDtEnvio(
                    Ambiente::getNrorg(), $nrorgint,
                    $prod['CDPRODUTOINT'], $dataAtual
                );

                SitLogtek::geraLogTek(
                    Ambiente::getNrorg(),
                    $nrorgint, $nrremessa, $prod['NRREMESSA'],
                    $prod['CDPRODUTOINT'], $dataAtual,
                    Ambiente::getCdOperador()
                );

                $i++;
            }

            $conn->flush();
            $conn->commit();
        } catch (\Exception $e) {
            $conn->rollback();
            return array($e->getMessage(), array());
        }

        return json_encode($json);
    }

}